
// -----------------------------------------------------------------------------------------------------------
// tweakset - a sample program to load tweaker output into your Arduino project
// -----------------------------------------------------------------------------------------------------------
//
// This program demonstrates how you can take register sets from the Tweaker program and load them into
// your Arduino project. If you are using Tweaker and come across a sound you'd like to use, you can use the
// "regs" button in Tweaker to cut and paste code into your Arduino application, and then trigger the code
// as shown below.
//
// When you press the "regs" button in Tweaker, the paste buffer on your PC will contain a text string that
// looks something like this:
//
//  ubyte regs[]={0,0,0,0,0,0,0,0,127,0,0,0,0,240,241,... };
//
// If you paste this into your Arduino IDE ( and rename as you see fit ), you can use the funtion shown below
// to trigger it at will. You need only to add the Tweaker output, and include the function loadRegisterSet()
// below.
//
// -----------------------------------------------------------------------------------------------------------

#include <GinSing.h>                                                // interface headder file
GinSing       GS;                                                   // create the class library

#define rcvPin  4                                                   // recieve pin  ( can be either 4 or 12 )
#define sndPin  3                                                   // transmit pin ( can be either 3 or 11 ) 
#define ovfPin  2                                                   // overflow pin ( can be either 2 or 10 )

 
 
  
  // this line is produced from the tweaker program - you can replace it with your own to duplicate sounds
  
    ubyte regs[]={1,104,0,0,0,0,0,0,127,0,0,0,0,240,241,1,128,255,0,9,91,0,47,0,126,126,27,0,12,144,144,
                 12,138,0,2,0,2,0,1,0,106,106,239,0,12,144,144,12,136,0,204,1,204,1,3,0,69,69,155,0,12,144,
                 144,12,0,0,0,0,0,0,0,0,127,0,0,0,0,240,241,1,128,0,0,0,0,0,0,0,0,0,0,0,0,144,144,12,128,0,
                 0,0,0,0,0,0,0,0,0,0,0,144,144,12,128,0,0,0,0,0,0,0,0,0,0,0,0,144,144,12,128,0,109,1,8,118,
                 0,0,127,0,24,49,12,0,0};

                 
// -----------------------------------------------------------------------------------------------------------
//  setup - system entry point for intialization ( called automatically on bootup )
// -----------------------------------------------------------------------------------------------------------

void setup ()
{
    
  GS.begin ( rcvPin , sndPin , ovfPin );                            // start the device
  
  loadRegisterSet ( regs , sizeof( regs ) );                        // load a sample register set
 
}

// -----------------------------------------------------------------------------------------------------------
// shutdown -- system exit point ( called locally )
// -----------------------------------------------------------------------------------------------------------

void shutdown()
{
  GS.end();                                                        // shutown the device
}


// -----------------------------------------------------------------------------------------------------------
// loop -- continuous update point ( called automatically after initialization )
// -----------------------------------------------------------------------------------------------------------

void loop (){}


// -----------------------------------------------------------------------------------------------------------
// loadRegisterSet -- load a  set of registers obtained from the Tweaker program
// -----------------------------------------------------------------------------------------------------------

void loadRegisterSet( ubyte regSet[] , int numRegs )
{              
  
  // reset the system to a default state
 
   GS.reset();
   
   
   // set the master amplitude to zero to mute the output until registers are all loaded

   GS.writeRegister ( MasterAmplitude , 0x0  , 0xff );


   // load the registers into the chip

   for ( int regIdx = 0; regIdx < numRegs; regIdx++ ) {
     
       if ( regIdx != MasterAmplitude ) 
         GS.writeRegister ( ( GSRegister )  regIdx , regSet [ regIdx ]  , 0xff );

  }
  
  
  // set the actual master amplitude to hear the loaded values
  
   GS.writeRegister ( MasterAmplitude , regSet [ MasterAmplitude ]  , 0xff );

}

