// ---------------------------------------------------------------------------------------------------------------------------------------------
// Welcome to preset mode!
// ---------------------------------------------------------------------------------------------------------------------------------------------
// 
// Preset mode is a very simple interface that lets you play some predefined sound effects built into the chip. This is a great way to get an idea
// of the capabilities of the chip and use the canned effects for simple interface sounds. Each effect only uses one of two available banks, so
// you can mix and match any two effects at the same time.
//
// In this example we will cycle through each of the available presets ( defined in GinSingDefs.h ). Although we are using only one of the two
// available banks, its easy to modify this code to use the other bank (1) to mix the effects together.
//
// ---------------------------------------------------------------------------------------------------------------------------------------------

#include <GinSing.h>                                   // interface header file
GinSing  GS;                                           //  create the class library from which all methods and data are accessed

#define rcvPin  4                                      // this is the pin used for receiving    ( can be either 4 or 12 )
#define sndPin  3                                      // this is the pin used for transmitting ( can be either 3 or 11 ) 
#define ovfPin  2                                      // this is the pin used for overflow control ( can be either 2 or 10 )

// ---------------------------------------------------------------------------------------------------------------------------------------------

void setup ()                                          // we are doing everything here, but you can also do this in the update loop
{
  
  GS.begin ( rcvPin , sndPin , ovfPin );               // start the device (required) and enter preset mode
  
  GinSingPreset * preset = GS.getPreset();             // get the preset mode interface
  preset->begin ();                                    // enter presetmode
  

  // cycle through the effects and load them into the first bank
  
  for ( int presetIdx = (int) SpaceWarp; presetIdx < (int) AmpMod; presetIdx++ )
  {
    
    preset->load    ( 0 , (GSPreset) presetIdx );      // load the selected preset on bank 0
    preset->trigger ( 0 );                             // trigger the preset on bank 0
    
    delay ( 1000 );                                    // listen to it for one second
    
    preset->release ( 0 );                             // release the preset
    
  }
  
  GS.end();                                            // end the device

}

void loop (){}
