// ---------------------------------------------------------------------------------------------------------------------------------------------
// Welcome to poly mode!
// ---------------------------------------------------------------------------------------------------------------------------------------------
// 
// The default mode for the GinSing libraryis polyphonic. In this mode, the system is configured to present 6 oscillators that
// are configured identically and all mixed to the master output. This mode is what you'd likely use if you were to create a 
// musical score that requires up to simultaneous notes, as illustrated below.
//
// In poly mode, the oscillators are configured to support a simple waveform (no modulation), and utilize ADSR envelope shapes
// for amplitude control. With minor changes to waveform shape and envelope you can simulate a variety of musical instruments.
// 

// ---------------------------------------------------------------------------------------------------------------------------------------------

#include <GinSing.h>                                           // interface header file
GinSing  GS;                                                   // create the class library from which all methods and data are accessed

#define rcvPin  4                                              // this is the pin used for receiving    ( can be either 4 or 12 )
#define sndPin  3                                              // this is the pin used for transmitting ( can be either 3 or 11 ) 
#define ovfPin  2                                              // this is the pin used for overflow control ( can be either 2 or 10 )

// ---------------------------------------------------------------------------------------------------------------------------------------------

void setup ()
{
  GS.begin ( rcvPin , sndPin , ovfPin );                       // start the device
  
  GinSingPoly * poly = GS.getPoly();                           // get the poly mode interface
  poly->begin ();                                              // enter poly mode

  
  // play a simple 3 tone 10 note ditty
  

  #define BASSVOICE 0                                          // use voice 0 (of 6) for the bass line
  #define LEADVOICE 1                                          // use voice 1 for the lead
  #define TREBVOICE 2                                          // use voice 2 for the treble
  
  
  // the notes can span over seven octaves, but the 3rd octave is pretty low to start with
  // this diddy just runs the C major scale, an inversion, and C major walk for the lead
  
  #define NumNotes 10
  GSNote bass[NumNotes] = { C_3 , E_3 , D_3 , F_3 , E_3 , G_3 , E_3 , F_3 , D_3 , E_3  };
  GSNote lead[NumNotes] = { C_6 , D_6 , E_6 , F_6 , G_6 , G_6 , F_6 , E_6 , D_6 , C_6  };
  GSNote treb[NumNotes] = { G_5 , E_5 , F_5 , D_5 , E_5 , C_5 , E_5 , D_5 , F_5 , E_5  };
   

  for ( int loopCnt = 0; loopCnt < 8; loopCnt++ )               // run through our ditty this many times
  {
    for ( int noteIdx = 0; noteIdx < NumNotes; noteIdx++ )      // cycle through the notes 
    { 
        poly->setNote ( BASSVOICE , bass [ noteIdx ] );         // set the current bassline note
        poly->trigger ( BASSVOICE );                            // trigger the envelope
        
        poly->setNote ( TREBVOICE , treb [ noteIdx ] );         // set the current treble note
        poly->trigger ( TREBVOICE );                            // trigger the envelope
        
        poly->setNote ( LEADVOICE , lead [ noteIdx ] );         // set the current leadline note
        poly->trigger ( LEADVOICE );                            // trigger the envelope
       
       delay ( 250 );                                           // wait 1/4 second before the next note
    }
  }

  // release the voices and wait for the envelopes to stop
    
  poly->release ( BASSVOICE );                                  // release the bassline envelope
  poly->release ( TREBVOICE );                                  // release the treble envelope
  poly->release ( LEADVOICE );                                  // release the leadline envelope
  
  delay ( 3000 );                                               // wait for the envelopes to finish
  GS.end();                                                     // end the device

}

void loop () {}
