#ifndef _GINSINGDEFS_DEF
#define _GINSINGDEFS_DEF

// ---------------------------------------------------------------------------------------------------------------------------------------------
// GinSing definitions - enumerations, constants and other definitions common to the GinSing library
// ---------------------------------------------------------------------------------------------------------------------------------------------
//
// These constants are used throughout the library. They are placed here for convenience. Some of enumerations apply only to certain modes and
// are labeled as such. It is important to note the hardware chip interface requires the use of 3 pins on the Ardiuno board as defined below.
// The pins are used to send and recieve communications from the chip.
// ---------------------------------------------------------------------------------------------------------------------------------------------
//



// variable type definitions
// ---------------------------------------------------------------------------------------------------------------------------------------------


typedef unsigned char ubyte;												// single unsigned byte      [ 0 to 255 (0xff)     ]
typedef signed   char sbyte;												// single signed byte        [ ( -127 to 127 )     ]
typedef unsigned int  uint;													// two byte unsigned integer [ 0 to 65535 (0xffff) ]
typedef unsigned long ulong;												// four byte unsigned integer [ 0 to (0xffffffff ) ]



// GSNote - musical note assignments ( note: there are gaps in the sequence to create 11 per 16 mapping so you can't cycle through them )
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSNote
{
	C_0 =  0 ,  CS_0 =  1 , D_0 =  2 , DS_0 =  3 , E_0 =  4 , F_0 =  5 , FS_0 =  6 , G_0 =  7 , GS_0 =  8 , A_0 =  9 , AS_0 = 10 , B_0 = 11 ,
	C_1 = 16 ,  CS_1 = 17 , D_1 = 18 , DS_1 = 19 , E_1 = 20 , F_1 = 21 , FS_1 = 22 , G_1 = 23 , GS_1 = 24 , A_1 = 25 , AS_1 = 26 , B_1 = 27 ,
	C_2 = 32 ,  CS_2 = 33 , D_2 = 34 , DS_2 = 35 , E_2 = 36 , F_2 = 37 , FS_2 = 38 , G_2 = 39 , GS_2 = 40 , A_2 = 41 , AS_2 = 42 , B_2 = 43 ,
	C_3 = 48 ,  CS_3 = 49 , D_3 = 50 , DS_3 = 51 , E_3 = 52 , F_3 = 53 , FS_3 = 54 , G_3 = 55 , GS_3 = 56 , A_3 = 57 , AS_3 = 58 , B_3 = 59 ,
	C_4 = 64 ,  CS_4 = 65 , D_4 = 66 , DS_4 = 67 , E_4 = 68 , F_4 = 69 , FS_4 = 70 , G_4 = 71 , GS_4 = 72 , A_4 = 73 , AS_4 = 74 , B_4 = 75 ,
	C_5 = 80 ,  CS_5 = 81 , D_5 = 82 , DS_5 = 83 , E_5 = 84 , F_5 = 85 , FS_5 = 86 , G_5 = 87 , GS_5 = 88 , A_5 = 89 , AS_5 = 90 , B_5 = 91 ,
	C_6 = 96 ,  CS_6 = 97 , D_6 = 98 , DS_6 = 99 , E_6 =100 , F_6 =101 , FS_6 =102 , G_6 =103 , GS_6 =104 , A_6 =105 , AS_6 =106 , B_6 =107 ,
	C_7 =112 ,  CS_7 =113 , D_7 =114 , DS_7 =115 , E_7 =116 , F_7 =117 , FS_7 =118 , G_7 =119 , GS_7 =120 , A_7 =121 , AS_7 =122 , B_7 =123 ,
};



// GSAllophone - synthesized voice phonemes morphed over time
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSAllophone
{
	// inflections - these can preceed any phoneme, and are applied on the single subseuqent phoneme
	// to use inflection over a larger span you can set the frequency and/or speed

	_SPEEDUP   = 1 ,    /* speed up          */
    _SPEEDDN   = 2 ,    /* slow down         */
	_VOLUP     = 3 ,    /* increase volume   */
	_VOLDN     = 4 ,    /* decrase volume    */
	_PITCHUP   = 5 ,    /* increase pitch    */
	_PITCHDN   = 6 ,    /* decrase pitch     */
	_BENDUP    = 7 ,    /* pitch bend up     */
	_BENDDN    = 8 , 	 /* pitch bend down   */
	
	
	// phonemes that create the words - these (along with inflections) are set into an array that uses _ENDPHRASE to terminate the sequence
	
	_A   = 192 ,  /* hat, fast, fan	          */	_AA  = 193 ,  /* father, fall             */	_AE  = 194 ,  /* gate, ate, ray           */
	_AIR = 195 ,  /* hair, stair, repair      */	_AU  = 196 ,  /* hot, clock, fox          */	_BE  = 197 ,  /* bear, bird, bead         */
	_BO  = 198 ,  /* bone, book, brown        */	_EB  = 199 ,  /* cab, crib, web           */	_OB  = 200 ,  /* bob, sub, tub            */
	_CH  = 201 ,  /* church, feature, march   */	_DE  = 202 ,  /* deep, date, divide       */	_DO  = 203 ,  /* do, dust, dog            */
	_ED  = 204 ,  /* could, bird              */	_OD  = 205 ,  /* bud, food                */	_E   = 206 ,  /* met, check, red          */	
	_EE  = 207 ,  /* see, even, feed          */	_ER  = 208 ,  /* fir, bird, burn          */	_F   = 209 ,  /* food, effort, off        */
	_GE  = 210 ,  /* get, gate, guest         */	_GO  = 211 ,  /* got, glue, god           */	_HE  = 212 ,  /* help, hand, hair         */
	_HO  = 213 ,  /* hoe, hot hung            */	_I   = 214 ,  /* sit, fix, pin            */	_IE  = 215 ,  /* mice, fight, white       */	
	_J   = 216 ,  /* dodge, jet, savage       */	_KE  = 217 ,  /* can't, clown, key        */	_KO  = 218 ,  /* comb, quick, coast       */
	_EK  = 219 ,  /* speak, task              */	_OK  = 220 ,  /* ook, took, october       */	_LE  = 221 ,  /* lake, alarm, lapel       */
	_LO  = 222 ,  /* clock, plus, hello       */	_M   = 223 ,  /* milk, famous, broom      */	_NE  = 224 ,  /* nip, danger, thin        */	
	_NO  = 225 ,  /* no, snow, on             */	_NGE = 226 ,  /* think, ping              */	_NGO = 227 ,  /* hung, song               */
	_OE  = 228 ,  /* go, hello, snow          */	_OI  = 229 ,  /* boy, toy, voice          */	_OO  = 230 ,  /* book, could, should      */
	_OU  = 231 ,  /* our, ouch, owl           */	_OR  = 232 ,  /* corn, four, your         */	_PE  = 233 ,  /* people, computer         */
	_PO  = 234 ,  /* pow, copy                */	_R   = 235 ,  /* ray, brain, over         */	_SE  = 236 ,  /* see, vest, plus          */
	_SO  = 237 ,  /* so, sweat                */	_SH  = 238 ,  /* ship, fiction, leash     */	_T   = 239 ,  /* part, little, sit        */
	_TH  = 240 ,  /* thin, month              */	_THH = 241 ,  /* there, that, this        */	_TS  = 242 ,  /* parts, costs, robots     */
	_U   = 243 ,  /* luck, jump, plus         */	_UE  = 244 ,  /* food, june               */	_V   = 245 ,  /* vest, even, twelve       */
	_W   = 246 ,  /* wool, sweat              */	_Y   = 247 ,  /* yes, yard, million       */	_Z   = 248 ,  /* zoo, zap                 */
	_ZH  = 249 ,  /* azure, treasure          */	_PA0 = 250 ,  /* 12 milliseocond pause    */	_PA1 = 251 ,  /* 48 millisecond pause     */
	_PA2 = 252 ,  /* 62 millisecond pause     */	_FD0 = 253 ,  /* 1 millisecond delay      */	_FD1 = 254 ,  /* 100 millisecond delay    */
    _FD2 = 255 ,  /* 600 millisecond delay    */
	
	_ENDPHRASE = 0 ,    /* terminate a string of allphones */

	
	
};


// GSPreset - built-in sound effects ( for preset mode )
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSPreset
{
	SpaceWarp    = 0  ,	Waba       =  1 ,	RandomThoughts =  2 ,	Gong         = 3 ,	Pwang        =  4 ,	Wow         =  5 ,
	Rananana     = 6  ,	Twarty     =  7 ,	Telly          =  8 ,	Pulsator     = 9 ,	Bound        = 10 ,	TipToe      = 11 ,
	Spokes       = 12 ,	Chopper    = 13 ,	Phazer         = 14 ,	PowerLines   = 15,	HeavyMetal1  = 16 ,	HeavyMetal2 = 17 ,
	ACMotor      = 18 ,	YaYa       = 19 ,	March          = 20 ,	NoiseChatter = 21,	BlipChatter  = 22 ,	Carney      = 23 ,
	EarthQuake   = 24 ,	MindProbe  = 25 ,	Siren          = 26 ,	Squaba       = 27,	SteamLoco    = 28 , FreqMod     = 29 , 
	AmpMod       = 30
};



// GSAttackDur - ADSR attack durations ( durations are quantized to these values as specified in milliseonds )
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSAttackDur
{
	AT_2MS   = 0x00, AT_8MS   = 0x01, AT_16MS  = 0x02, AT_24MS  = 0x03, AT_38MS   = 0x04, AT_56MS   = 0x05, AT_68MS   = 0x06, AT_80MS    = 0x07,
	AT_100MS = 0x08, AT_250MS = 0x09, AT_500MS = 0x0a, AT_800MS = 0x0b, AT_1000MS = 0x0c, AT_2800MS = 0x0d, AT_5600MS = 0x0e, AT_11200MS = 0x0f
};



// GSDecRelDur - ADSR decay / release durations ( durations are quantized to these values as specified in milliseonds )
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSDecRelDur
{
	DR_2MS  = 0x00, DR_6MS   = 0x01, DR_10MS  = 0x02, DR_15MS  = 0x03, DR_23MS  = 0x04, DR_34MS   = 0x05, DR_40MS   = 0x06, DR_48MS   = 0x07,
	DR_59MS = 0x08, DR_145MS = 0x09, DR_292MS = 0x0a, DR_455MS = 0x0b, DR_575MS = 0x0c, DR_1500MS = 0x0d, DR_2785MS = 0x0e, DR_4873MS = 0x0f
};



// GSWaveType - waveform types ( used for poly and synth modes )
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSWaveType
{
	SINE     ,																// sinusoidal 
	TRIANGLE ,																// linear rise, linear fall
	SAWTOOTH ,																// instant rise, linear fall
	RAMP     ,																// linear rise, instant fall
	PULSE    ,																// instant rise, instant fall
	NOISE    ,																// random amplitude noise
	LEVEL    ,																// fixed DC offset
};



// GSWaveMode - waveform modes
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSWaveMode
{
	SYMMETRIC ,																// waveform oscillates symmetrically around zero 
	POSITIVE  ,																// waveform is only positive ( waveform shifted so minimum is at zero )
};



// GSSynthBank - bank selection ( used for synth mode only )
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSSynthBank
{
	BANK_A ,																// bank A has three oscillators ( A1, A2, A3 ) to mixer A
	BANK_B ,																// bank B has three oscillators ( B1, B2, B3 ) to mixer B
};


// GSMasterMixer - master mixer selection
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSMasterMixer
{
	MIX_A  =  0x00 ,														// mixer 1 control ( mixes oscillators A 1-3 )
	MIX_B  =  0x01 ,														// mixer 2 control ( mixes oscillators B 1-3 )
	MIX_ALL = 0xff ,														// both mixers
	
};


// GSSynthOsc -oscillators by type ( synth mode only )
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSSynthOsc
{
	OSC_1   = 0x10 ,															// oscillator #1 ( typically basic tone generator )
	OSC_2   = 0x11 ,															// oscillator #2 ( typically amplitude modulator  )
	OSC_3   = 0x12 ,															// oscillator #3 ( typically frequency modulator  )
	OSC_ALL = 0xff ,															// all oscillators
};



// GSSynthPatch - patch settings ( synth mode only )
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSSynthPatch
{
	
	// [OSC] -> [MIX] : any oscillator can be sent directly to the mixer ( both banks )
	
	OSC_1_TO_MIXER                  = 0x0001 ,								// send oscillator 1 output to the mixer
	OSC_2_TO_MIXER                  = 0x0002 ,								// send oscillator 2 output to the mixer
	OSC_3_TO_MIXER                  = 0x0004 ,								// send oscillator 3 output to the mixer
	
	
	// [OSC2] -> AMPMOD [OSC1] : oscillators 2 can amplitude modulate and sync oscillators 1 ( in their respective bank )
	
	OSC_2_AMPMOD_OSC_1              = 0x0800 ,								// use oscillator 2 to amplitude modulate oscillator 1
	OSC_2_AMPMOD_OSC_1_50PERC       = 0x1000 ,								// reduce amplitude modulation effect by 50%
	OSC_2_RINGMOD_OSC_1             = 0x2000 ,								// use oscillator 2 to sync oscillator 1
	
	
	// [OSC3] -> FRQMOD [OSC1] : oscillators 3 can frequency modulate oscillators 1 ( in their respective bank )
	
	OSC_3_FRQMOD_OSC_1              = 0x4000 ,								// use oscillator 3 to frequency modulate oscillator 1
	OSC_3_FRQMOD_OSC_1_50PERC       = 0x8000 ,								// reduce freqauency modulation effect by 50%
	
	
	// [B1 OSC] -> AMPMOD [MIX] , [B1 OSC] -> RINGMOD [MIX]
	// bank B oscillator 1 is unique in that it can amplitude modulate the main mixer and/or sync all other oscillators at once ( either bank as target )
	
	OSC_B1_AMPMOD_MIXER             = 0x0008 ,								// use bank B oscillator 1 output to amplitude modulate selected mixer
	OSC_B1_AMPMOD_MIXER_50PERC      = 0x0010 ,								// reduce AM mixer effect by 50%
	OSC_B1_RINGMOD_MIXER            = 0x0020 ,								// use bank B oscillator 1 to ring modulate selected mixer
	
	
	// [B OSC] -> PWM [A OSC]
	// bank 2 B oscillators are unique in that they can pulse width ampltidue modulate selected oscillators on bank A
	
	OSC_B1_PWM_OSC_1                = 0x0100 ,								// use bank B oscillator 1 to pulse modulate oscillator 1 (either bank)
	OSC_B2_PWM_OSC_2                = 0x0200 ,								// use bank B oscillator 2 to pulse modulate oscilaltor 2 (either bank)
	OSC_B3_PWM_OSC_3                = 0x0400 ,								// use bank B oscillator 3 to pulse modulate oscilaltor 3 (either bank)
};




// GSCommand - low level interface commands
// ---------------------------------------------------------------------------------------------------------------------------------------------


enum GSCommand 
{
	
	// global                                                                  arguments
	// --------------------													-----------------------------------------------------------------------
	
	ReadOneByte           =   0 ,											// 1 | addr                   | polls 1 byte at register address
	WriteOneByte          =   1 ,											// 2 | addr, 1 data byte      | writes 1 byte to register address
	WriteTwoBytes         =   2 ,											// 3 | addr, 2 data bytes     | writes two bytes to register address
	WriteThreeBytes       =   3 ,											// 4 | addr, 3 data bytes     | writes three bytes to register address
	WriteOneByteWithMask  =   4 ,											// 3 | addr, data byte, mask  | writes 1 masked byte to register address
	
	ClearMixersAB         =   6 ,											// 0 | sets all mixer and oscillator values to zero
	RampToTargetsAB       =   7 ,											// 0 | calculates ramp values and activate ramp and target options
	SetVoiceNote          =   8 ,											// 1 | 1 byte note value      | sets voice frequency to musical note val
	SetVoiceFrequency     =   9 ,											// 2 | 2 bytes frequency      | sets voice frequency to secified value 
	SetVoiceDelay         =  10 ,											// 1 | 1 byte delay           | set voice delay to specified value
	SetVoiceDefaults      =  11 ,											// 0 | sets voice values to defaults
	
	TurnQOn               =  14 ,											// 0 | sets the Q output pin high
	TurnQOff              =  15 ,											// 0 | sets the Q output pin low
	
	
	// mixer / oscillators A        mixer / oscillators B                   // note: there are unique commands specifying the oscillator/mixer bank
	//  -----------------------     ------------------------                // --------------------------------------------------------------------
	
	ClearMixerAndOsc_A    =  70 ,   ClearMixerAndOsc_B      = 102 ,			// 0 | sets mixer and oscillator values to zero
	RampToTargets_A       =  71 ,   RampToTargets_B         = 103 ,			// 0 | calculates ramp values and activate ramp and target options 
	
	LoadNoteOsc_A1        =  72 ,   LoadNoteOsc_B1          = 104 ,			// 1 | 1 byte note value | loads note value for osc 1
	LoadNoteOsc_A2        =  73 ,   LoadNoteOsc_B2          = 105 ,			// 1 | 1 byte note value | loads note value for osc 2
	LoadNoteOsc_A3        =  74 ,   LoadNoteOsc_B3          = 106 ,			// 1 | 1 byte note value | loads note value for osc 3
	LoadSoundMixer_A      =  75 ,   LoadSoundMixer_B        = 107 ,			// 1 | 1 byte sound fx   | loads sound effect into mixer/oscillators
	LoadFreqOsc_A1        =  76 ,   LoadFreqOsc_B1          = 108 ,			// 2 | 2 bytes frequency | loads specified frequency into osc 1
	LoadFreqOsc_A2        =  77 ,   LoadFreqOsc_B2          = 109 ,			// 2 | 2 bytes frequency | loads specified ferquency into osc 2
	LoadFreqOsc_A3        =  78 ,   LoadFreqOsc_B3          = 110 ,			// 2 | 2 bytes frequency | loads specified frequency into osc 3
	
	TriggerOsc_A1         =  80 ,   TriggerOsc_B1           = 112 ,			// 0 | start the envelope for osc 1
	TriggerOsc_A2         =  81 ,   TriggerOsc_B2           = 113 ,			// 0 | start the envelope for osc 2
	TriggerOsc_A3         =  82 ,   TriggerOsc_B3           = 114 ,			// 0 | start the envelope for osc 3
	TriggerMixer_A        =  83 ,   TriggerMixer_B          = 115 ,			// 0 | start the mixer envelope
	ReleaseOsc_A1         =  84 ,   ReleaseOsc_B1           = 116 ,			// 0 | release the envelope for osc 1
	ReleaseOsc_A2         =  85 ,   ReleaseOsc_B2           = 117 ,			// 0 | release the envelope for osc 2
	ReleaseOsc_A3         =  86 ,   ReleaseOsc_B3           = 118 ,			// 0 | release the envelope for osc 3
	ReleaseMixer_A        =  87 ,   ReleaseMixer_B          = 119 ,			// 0 | release the mixer envelope
	
	LoadPlayNoteOsc_A1    =  88 ,   LoadPlayNoteOsc_B1      = 120 ,			// 1 | 1 byte note value | loads the note and starts env osc 1
	LoadPlayNoteOsc_A2    =  89 ,   LoadPlayNoteOsc_B2      = 121 ,			// 1 | 1 byte note value | loads the note and starts env osc 2
	LoadPlayNoteOsc_A3    =  90 ,   LoadPlayNoteOsc_B3      = 122 ,			// 1 | 1 byte note value | loads the note and starts env osc 3
	
	ResetToVoice_A        =  91 ,   ResetToVoice_B          = 123 ,			// 0 | resets mixer to voice parameters
	
	LoadPlayFreqOsc_A1    =  92 ,   LoadPlayFreq_B1         = 124 ,			// 2 | 2 bytes frequency | loads the frequency and starts env osc 1
	LoadPlayFreqOsc_A2    =  93 ,   LoadPlayFreq_B2         = 125 ,			// 2 | 2 bytes frequency | loads the frequency and starts env osc 2
	LoadPlayFreqOsc_A3    =  94 ,   LoadPlayFreq_B3         = 126 ,			// 2 | 2 bytes frequency | loads the frequency and starts env osc 3
	
	CmdHeader             =  27 											// all commands are prefixed by this 1 byte header. this is added
																			// internally in sendCommand but is here for reference purposes
	
};



// GSRegister - hardware registers on the sound chip identify all the operating parameters and are only valid in command mode
// ---------------------------------------------------------------------------------------------------------------------------------------------

enum GSRegister 
{
	
	// mixer A                        mixer B
	//  ----------------------         ------------------------
	
	A_MixControl_0        =    0 ,    B_MixControl_0         =  64 ,
	A_MixControl_1         =   1 ,    B_MixControl_1         =  65 ,
	A_OscDistort_1         =   2 ,    B_OscDistort_1         =  66 ,
	A_OscDistort_2         =   3 ,    B_OscDistort_2         =  67 ,
	A_OscDistort_3         =   4 ,    B_OscDistort_3         =  68 ,
	A_OscPWM_1             =   5 ,    B_OscPWM_1             =  69 ,
	A_OscPWM_2             =   6 ,    B_OscPWM_2             =  70 ,
	A_OscPWM_3             =   7 ,    B_OscPWM_3             =  71 ,
	A_Amplitude            =   8 ,    B_Amplitude            =  72 ,
	A_AmplitudeTarget      =   9 ,    B_AmplitudeTarget      =  73 ,
	A_AmplitudeXLow        =  10 ,    B_AmplitudeXLow        =  74 ,
	A_AmplitudeXHigh       =  11 ,    B_AmplitudeXHigh       =  75 ,
	A_EnvelopeControl      =  12 ,    B_EnvelopeControl      =  76 ,
	A_EnvelopeAttack       =  13 ,    B_EnvelopeAttack       =  77 , 
	A_EnvelopeDecay        =  14 ,    B_EnvelopeDecay        =  78 ,
	A_EnvelopeRelease      =  15 ,    B_EnvelopeRelease      =  79 ,
	
	
	// oscillator A1                  oscillator A2                     oscillator A3
	// ------------------------       -----------------------------     -----------------------------
	A1_Control             =  16 ,    A2_Control             =  32 ,    A3_Control              = 48 ,
	A1_FrequencyFine       =  17 ,    A2_FrequencyFine       =  33 ,    A3_FrequencyFine        = 49 ,
	A1_FrequencyLow        =  18 ,    A2_FrequencyLow        =  34 ,    A3_FrequencyLow         = 50 ,
	A1_FrequencyHigh       =  19 ,    A2_FrequencyHigh       =  35 ,    A3_FrequencyHigh        = 51 , 
	A1_FrequencyTargetLow  =  20 ,    A2_FrequencyTargetLow  =  36 ,    A3_FrequencyTargetLow   = 52 ,
	A1_FrequencyTargetHigh =  21 ,    A2_FrequencyTargetHigh =  37 ,    A3_FrequencyTargetHigh  = 53 ,
	A1_FrequencyXLow       =  22 ,    A2_FrequencyXLow       =  38 ,    A3_FrequencyXLow        = 54 ,
	A1_FrequencyXHigh      =  23 ,    A2_FrequencyXHigh      =  39 ,    A3_FrequencyXHigh       = 55 ,
	A1_Amplitude           =  24 ,    A2_Amplitude           =  40 ,    A3_Amplitude            = 56 ,
	A1_AmplitudeTarget     =  25 ,    A2_AmplitudeTarget     =  41 ,    A3_AmplitudeTarget      = 57 ,
	A1_AmplitudeXLow       =  26 ,    A2_AmplitudeXLow       =  42 ,    A3_AmplitudeXLow        = 58 ,
	A1_AmplitudeXHigh      =  27 ,    A2_AmplitudeXHigh      =  43 ,    A3_AmplitudeXHigh       = 59 ,
	A1_EnvelopeControl     =  28 ,    A2_EnvelopeControl     =  44 ,    A3_EnvelopeControl      = 60 ,
	A1_EnvelopeAttack      =  29 ,    A2_EnvelopeAttack      =  45 ,    A3_EnvelopeAttack       = 61 ,
	A1_EnvelopeDecay       =  30 ,    A2_EnvelopeDecay       =  46 ,    A3_EnvelopeDecay        = 62 ,
	A1_EnvelopeRelease     =  31 ,    A2_EnvelopeRelease     =  47 ,    A3_EnvelopeRelease      = 63 ,
	
	
	// oscillator B1                  oscillator B2                     oscillator B3
	// ------------------------       -----------------------------     -----------------------------
	B1_Control             =  80 ,    B2_Control             =  96 ,    B3_Control             = 112 ,
	B1_FrequencyFine       =  81 ,    B2_FrequencyFine       =  97 ,    B3_FrequencyFine       = 113 ,
	B1_FrequencyLow        =  82 ,    B2_FrequencyLow        =  98 ,    B3_FrequencyLow        = 114 ,
	B1_FrequencyHigh       =  83 ,    B2_FrequencyHigh       =  99 ,    B3_FrequencyHigh       = 115 , 
	B1_FrequencyTargetLow  =  84 ,    B2_FrequencyTargetLow  = 100 ,    B3_FrequencyTargetLow  = 116 ,
	B1_FrequencyTargetHigh =  85 ,    B2_FrequencyTargetHigh = 101 ,    B3_FrequencyTargetHigh = 117 ,
	B1_FrequencyXLow       =  86 ,    B2_FrequencyXLow       = 102 ,    B3_FrequencyXLow       = 118 ,
	B1_FrequencyXHigh      =  87 ,    B2_FrequencyXHigh      = 103 ,    B3_FrequencyXHigh      = 119 ,
	B1_Amplitude           =  88 ,    B2_Amplitude           = 104 ,    B3_Amplitude           = 120 ,
	B1_AmplitudeTarget     =  89 ,    B2_AmplitudeTarget     = 105 ,    B3_AmplitudeTarget     = 121 ,
	B1_AmplitudeXLow       =  90 ,    B2_AmplitudeXLow       = 106 ,    B3_AmplitudeXLow       = 122 ,
	B1_AmplitudeXHigh      =  91 ,    B2_AmplitudeXHigh      = 107 ,    B3_AmplitudeXHigh      = 123 ,
	B1_EnvelopeControl     =  92 ,    B2_EnvelopeControl     = 108 ,    B3_EnvelopeControl     = 124 ,
	B1_EnvelopeAttack      =  93 ,    B2_EnvelopeAttack      = 109 ,    B3_EnvelopeAttack      = 125 ,
	B1_EnvelopeDecay       =  94 ,    B2_EnvelopeDecay       = 110 ,    B3_EnvelopeDecay       = 126 ,
	B1_EnvelopeRelease     =  95 ,    B2_EnvelopeRelease     = 111 ,    B3_EnvelopeRelease     = 127 ,
	
	
	// chip control
	// ---------------------------
	
	MiscellaneousControl   = 128 ,    MasterAmplitude        = 136 ,
	SpeechControl          = 129 ,    PortControl            = 137 ,
	SpeechFrequencyLow     = 130 ,    Output_A1              = 138 ,
	SpeechFrequencyHigh    = 131 ,    Output_A2              = 139 ,
	TransitionSpeed        = 132 ,    Output_A3              = 140 ,
	InternalClock          = 133 ,    Output_B1              = 141 ,
	PitchBend_A            = 134 ,    Output_B2              = 142 ,
	PitchBend_B            = 135 ,    Output_B3              = 143
	
};



#endif // _GINSINGDEFS_DEF

