#ifndef _GINSINGMASTER_DEF
#define _GINSINGMASTER_DEF


// ---------------------------------------------------------------------------------------------------------------------------------------------
// GinSingMaster - the component of the GinSing system that handles master functions
// ---------------------------------------------------------------------------------------------------------------------------------------------
//
// The master class allows you to control global functions on the chip, and provides the interface to the output mixers. The mixers are arranged
// into 2 banks and each indivually control 3 oscillators. Depending on the mode you are in, the usefullness of these mixers vary. For example,
// in voice mode the mixers are controlled by the voice synthesizer and modifying them may produce unusual effects (or no effect at all ). In
// synth mode you have the most control over the mixers. The mixers can run either at a fixed value ( via SetAmplitude ), or can use an ADSR 
// envelope generator ( using trigger()/release() ).
//
// ---------------------------------------------------------------------------------------------------------------------------------------------


class GinSingMaster
{
	
public:
	
	
	// global functions
	
	void setMasterAmplitude ( float ampltiude );										// set the master output amplitude  ( 0.0 to 1.0 )
	void setMasterAmplitudeVal ( ubyte ampVal );										// set the mixer output amplitude by value ( 0 to 127 )

	void enableUserOutput   ( bool enable );											// enable or disable the user output (Q)
	void enableSlowClock    ( bool enable );											// enable or disable clock slowdown ( diagnostic only )
	
	
	// main mixer functions
	
	void setAmplitude   ( GSMasterMixer mixerIdx , float amplitude );					// set the mixer output amplitude ( 0.0 to 1.0 )
	void setAmplitudeVal( GSMasterMixer mixerIdx , ubyte ampVal );						// set the mixer output amplitude ( 0 - 127 )

	
	void trigger       ( GSMasterMixer mixerIdx );										// trigger a mixer envelope
	void release       ( GSMasterMixer mixerIdx );										// release a mixer envelope
	

	void setEnvelope   ( GSMasterMixer mixerIdx ,
						 GSAttackDur   attackDur  , float attackAmp  ,					// set the ADSR envelope
						 GSDecRelDur   decayDur   , float decayAmp   ,					// amplitudes vary from 0.0 to 1.0
						 GSDecRelDur   releaseDur , float releaseAmp );					// durations are limited to selections in GinSingDefs.h

	void setEnvelopeVal  ( GSMasterMixer mixerIdx ,										// set ADSR by integer values
						   GSAttackDur attackDur  , ubyte attackAmpVal  ,
						   GSDecRelDur decayDur   , ubyte decayAmpVal   ,
						   GSDecRelDur releaseDur , ubyte releaseAmpVal );
	

	void enableAmpRamp  ( GSMasterMixer mixerIdx , bool enable );						// enable or disable amplitude ramping
	void setAmpRamp     ( GSMasterMixer mixerIdx , float relRate );						// set mixer to ramp amplitude at relative rate ( 0.0 - 1.0 )
	void setAmpRampVal  ( GSMasterMixer mixerIdx , uint relRateVal );					// set ampltiude ramp relative rate as an integer ( 0 - 127 )
	

	void enableAmpTarget  ( GSMasterMixer mixerIdx , bool enable );						// enable or disable amplitude targeting
	void setAmpTarget  ( GSMasterMixer mixerIdx , float amplitude , float relRate );	// set a target amplitude to move towards at a relative rate ( 0.0 to 1.0 )
	void setAmpTargetVal ( GSMasterMixer mixIdx , ubyte ampTgtVal , uint relRateVal );	// set amplitude targeting parameters with integers
	
	
	void setBendFreq    ( GSMasterMixer mixerIdx , float freqHz );						// specify a bend frequency ( Hz )
	void setBendFreqVal ( GSMasterMixer mixerIdx , ubyte freqVal );						// set bend frequency as an integer value
							
	
	
	// internal methods
	
	void  reset();																		// configure the system to a default state

	
};

#endif // _GINSINGMASTER_DEF

