// ---------------------------------------------------------------------------------------------------------------------------------------------
// GinSingPreset - preset effect support the arduino GinSing shield
// ---------------------------------------------------------------------------------------------------------------------------------------------
// 

#include "GinSing.h"

static GSCommand loadCmds    [] = { LoadSoundMixer_A , LoadSoundMixer_B };
static GSCommand triggerCmds [] = { TriggerMixer_A   , TriggerMixer_B   };
static GSCommand releaseCmds [] = { ReleaseMixer_A   , ReleaseMixer_B   };

// ---------------------------------------------------------------------------------------------------------------------------------------------
// begin - setup system for preset effect mode
// ---------------------------------------------------------------------------------------------------------------------------------------------

void GinSingPreset::begin()
{

	// reset the master settings
	
	gsPtr->getMaster()->reset ();

}

// ---------------------------------------------------------------------------------------------------------------------------------------------
// preview - preview preset mode
// ---------------------------------------------------------------------------------------------------------------------------------------------

void GinSingPreset::preview()
{
	// trigger one effect on the first bank
	
	setAmplitude ( 0 , 0.50f );
	load         ( 0 , Carney );
	trigger      ( 0 );

	delay ( 1000 );
	
	
	// tigger another effect on the second bank

	setAmplitude ( 1 , 0.50f  );
	load         ( 1 , TipToe );
	trigger      ( 1 );

	delay ( 2000 );
	
	
	// release the effects
	
	release ( 0 );
	release ( 1 );
}

// ---------------------------------------------------------------------------------------------------------------------------------------------
// load - load the specified preset sound effect into a bank
// ---------------------------------------------------------------------------------------------------------------------------------------------

void GinSingPreset::load ( ubyte bankIdx , GSPreset presetIdx )
{
	
	// send the command directly to the register
	
	gsPtr->sendCommand ( loadCmds [ bankIdx ] , presetIdx );
}

// ---------------------------------------------------------------------------------------------------------------------------------------------
// Trigger - trigger the ampltiude envelope
// ---------------------------------------------------------------------------------------------------------------------------------------------

void GinSingPreset::trigger ( ubyte bankIdx )
{	
	// send the command directly to the register
	
	gsPtr->sendCommand ( triggerCmds [ bankIdx ] );
}


// ---------------------------------------------------------------------------------------------------------------------------------------------
// Release - release the ampltiude envelope
// ---------------------------------------------------------------------------------------------------------------------------------------------

void GinSingPreset::release ( ubyte bankIdx )
{	
	// send the command directly to the register
	
	gsPtr->sendCommand ( releaseCmds [ bankIdx ] );
}


// ---------------------------------------------------------------------------------------------------------------------------------------------
// setAmplitude - set the preset effect amplitude
// ---------------------------------------------------------------------------------------------------------------------------------------------

void GinSingPreset::setAmplitude ( ubyte bankIdx , float amplitude )
{	
	// compute amplitude as a signed byte
	
	ubyte ampCmd = (sbyte) ( amplitude * 127.0f );
	
	
	// send the amplitude command to both mixers
	
	if ( bankIdx == 0 )
		gsPtr->sendCommand ( WriteOneByte , A_Amplitude , ampCmd );
	
	if ( bankIdx == 1 )
		gsPtr->sendCommand ( WriteOneByte , B_Amplitude , ampCmd );
}


