#ifndef _GINSING_PRESET_DEF
#define _GINSING_PRESET_DEF

// ---------------------------------------------------------------------------------------------------------------------------------------------
// GinSingPreset - preset sound effect interface
// ---------------------------------------------------------------------------------------------------------------------------------------------
//
// Preset mode is a very simple interface that lets you play some predefined sound effects built into the chip. This is a great way to get an idea
// of the capabilities of the chip and use the canned effects for simple interface sounds. Each effect only uses one of two available banks, so
// you can mix and match any two effects at the same time.
//
// ---------------------------------------------------------------------------------------------------------------------------------------------
//
// A simple example to trigger a couple of effects looks like:
//
// GinSingPreset *preset = GS.getPrest();										// get the preset mode functions
//   
//   preset->begin();															// switch to preset mode
//   preset->load ( 0 , Carney );  preset->trigger ( 0 );						// load and play the Carney effect on bank 1
//   preset->load ( 1 , TipToe );  preset->trigger ( 1 );						// load and play the TipToe effect on bank 2
//   delay ( 2000 );															// wait to hear the sound
//   release ( 0 ); release ( 1 );												// release the effects
//
// ---------------------------------------------------------------------------------------------------------------------------------------------


class GinSingPreset
{
		
public:

	
	// preset mode parameters

	
	enum PresetParams {
		
		NumBanks = 2,															// number of preset banks available
	};

	
	// preset mode methods

	void begin        ();														// set up for voice synthesis mode
	void preview      ();														// preview default voice mode setup
	
	void load         ( ubyte bankIdx , GSPreset presetIdx  );					// load a preset into a bank
	void trigger      ( ubyte bankIdx );										// trigger current preset in a bank
	void release      ( ubyte bankIdx );										// release the current preset effect
	void setAmplitude ( ubyte bankIdx , float amplitude  );						// set amplitude for a bank
	
};

#endif // _GINSING_PRESET_DEF

