#ifndef _GINSING_VOICE_DEF
#define _GINSING_VOICE_DEF

// ---------------------------------------------------------------------------------------------------------------------------------------------
// GinSingVoice - voice synthezer mode interface
// ---------------------------------------------------------------------------------------------------------------------------------------------
// 
// Voice mode allows you to create a synthesized human (or otherwise) voice. The chip has very sophisticated synthesis that allows for a lot
// of modification in how the voice talks. In addition to standard things like speed and frequency, you can also control inflection per
// phoneme, and control how the synthesizer blends between the phonemes. In voice mode the chip takes control of all of the oscilaltors and
// mixers to create the final output.
//
// ---------------------------------------------------------------------------------------------------------------------------------------------
//
// In this simple example, we say hello with some inflection:
//
//  GinSingVoice = *voice = GS.getVoice();														// get the voice mode interface
//  voice->begin();																				// switch into voice mode
//
//   GSAllophone  hello[] = {  _HE , _PITCHUP , _E , _LO , _PITCHDN , _OE , _ENDPHRASE };		// create a phrase array "hello"
//   voice->speak ( hello );																	// speak the phrase
//   voice->delay ( voice->getMillis( hello ) );												// wait to hear it speak
//
// ---------------------------------------------------------------------------------------------------------------------------------------------


class GinSingVoice
{
		
public:
	
	// voice mode methods
	
	void begin    ();														// set up for voice synthesis mode
	void preview  ();														// preview default voice mode setup
	
	void speak         ( GSAllophone * phrase );							// speak a set of allophones ( terminated with ENDPHRASE )
	int  getMillis     ( GSAllophone * phrase );							// compute the length of time the phrase will last when spoken (ms)
	
	void setNote       ( GSNote noteIdx       );							// set the base musical note for speech
	void setFrequency  ( float freqHz         );							// set the base frequency for speech
	void setBlendSpeed ( float relSpeed       );							// set the relative speed ( 0.0 - 1.0 ) to blend between phonemes
	void setDelay      ( float relDelay       );							// set the relative delay ( 0.0f - 1.0 ) between phonemes
};

#endif // _GINSING_VOICE_DEF

